@@ -6,12 +6,15 @@ from .api.core import (
     is_legit_allele,
     is_target_gene,
     get_default_allele,
+    get_exon_ends,
+    get_exon_starts,
     get_function,
     get_paralog,
     get_priority,
     get_ref_allele,
     get_region,
     get_score,
+    get_strand,
     get_variant_impact,
     get_variant_synonyms,
     list_alleles,
